<?php
header('Content-Type: text/plain');

$postData = file_get_contents('php://input');
$data = json_decode($postData, true);

// Log the received data for debugging (remove this in production)
echo "Received data: " . print_r($data, true) . "\n";

$trials = $data['results'] ?? [];
$participantID = $data['participantId'] ?? 'Unknown'; // Fallback in case participant ID isn't set

// Define the path to the CSV file
$filePath = __DIR__ . '/reaction_recordings/reactions.csv';

// Ensure the directory exists and is writable
if (!file_exists(dirname($filePath))) {
    mkdir(dirname($filePath), 0777, true); // Adjust permissions as necessary
}

// Open the file for writing; create if does not exist, append if it does
$file = fopen($filePath, file_exists($filePath) ? 'a' : 'w');
if (!$file) {
    echo "Failed to open file.";
    exit;
}

// Add CSV headers if creating the file for the first time
if (!file_exists($filePath) || filesize($filePath) == 0) {
    fputcsv($file, ['ParticipantID', 'Text', 'Target', 'ReactionTime']);
}

// Check if trials data is available and is an array
if (!empty($trials) && is_array($trials)) {
    foreach ($trials as $trial) {
        if (isset($trial['text'], $trial['target'], $trial['reactionTime'])) {
            // Write each trial's data to the CSV file
            fputcsv($file, [$participantID, $trial['text'], $trial['target'], $trial['reactionTime']]);
        } else {
            echo "Missing data in some trials.\n";
        }
    }
    echo "Data recorded successfully.\n";
} else {
    echo "No data received or data is not an array.\n";
}

// Close the file
fclose($file);
?>
